<?php
// Own namespace
namespace Org\Mxchange\CoreFramework\Filter\Verifier\Password;

// Import framework stuff
use Org\Mxchange\CoreFramework\Filter\BaseFilter;
use Org\Mxchange\CoreFramework\Filter\Filterable;
use Org\Mxchange\CoreFramework\Request\Requestable;
use Org\Mxchange\CoreFramework\Response\Responseable;

/**
 * A concrete filter for validating the password. This filter may intercept
 * the filter chain if no password is given or the password is invalid
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2020 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class PasswordVerifierFilter extends BaseFilter implements Filterable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	private function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this filter class
	 *
	 * @return	$filterInstance		An instance of this filter class
	 */
	public static final function createPasswordVerifierFilter () {
		// Get a new instance
		$filterInstance = new PasswordVerifierFilter();

		// Return the instance
		return $filterInstance;
	}

	/**
	 * Executes the filter with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 * @throws	FilterChainException	If this filter fails to operate
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		// Get password
		$password = $requestInstance->getRequestElement('pass');

		// Is the password still not set?
		if (is_null($password)) {
			// Not found in form so stop the filtering process
			$requestInstance->requestIsValid(false);

			// Add a message to the response
			$responseInstance->addFatalMessage('password_unset');

			// Abort here
			throw new FilterChainException($this, self::EXCEPTION_FILTER_CHAIN_INTERCEPTED);
		} elseif (empty($password)) {
			// Password is empty
			$requestInstance->requestIsValid(false);

			// Add a message to the response
			$responseInstance->addFatalMessage('password_empty');

			// Abort here
			throw new FilterChainException($this, self::EXCEPTION_FILTER_CHAIN_INTERCEPTED);
		}
	}

}
